@@ -117,7 +117,7 @@ class mPrefs:
       if (know_autosync_id == 0):# and (activate_autosync==True):
 #        print 'try to add autosync:'
         diff = datetime.timedelta(minutes=autosync_interval)
-        timer = datetime.datetime.now().replace(tzinfo=dateutil.tz.tzlocal) + diff
+        timer = datetime.datetime.now().replace(tzinfo=dateutil.tz.tzlocal()) + diff
         know_autosync_id = osso.alarmd.add_alarm(time.mktime(timer.timetuple()),flags=385,exec_name='python /usr/lib/mcalendar/mcalendar_sync.py',recurrence=autosync_interval,recurrence_count=-1)
         self.set_value('autosync_alarm_id',str(know_autosync_id))
         self._save_pref_file()
