@@ -88,6 +88,7 @@ class GCalendar(Calendar):
     for participant in distant_event.who:
       if participant.attendee_status != None:
         local_event.who.append(Attendee(participant.email,participant.name,participant.attendee_status.value))
+#        LogIt().append('DEBUG:'+str(participant.attendee_status.value))
 #    print 'Imported event : '+str(local_event.title)+' at :'+str(local_event.start_datetime)+' uuid :'+ str(local_event.uuid)
     LogIt().append('Imported event : '+str(local_event.title)+' at :'+str(local_event.start_datetime)+' uuid :'+ str(local_event.uuid))
     local_event.save_to_db()
@@ -192,7 +193,7 @@ class GSync:
         else:
           distant_event.when.append(gdata.calendar.When(start_time=self.convert_local_datetime(local_event.start_datetime), end_time=self.convert_local_datetime(local_event.end_datetime)))
         for attendee in local_event.who:
-          distant_event.who.append(gdata.calendar.Who(email=attendee.email,name=attendee.name))
+          distant_event.who.append(gdata.calendar.Who(email=attendee.email,name=attendee.name,statut=attendee.statut))
 #          distant_attendee = gdata.calendar.Who()
 #          distant_attendee.name = attendee.name
 #          distant_attendee.email = attendee.email
@@ -204,7 +205,7 @@ class GSync:
         local_event.google_event_id = new_distant_event.id.text
         local_event.google_cal_id = urllib.unquote(new_distant_event.id.text.split('/')[5])  
         local_event.save_to_db()
-        print 'Uploaded event : ' + str(local_event.title) 
+        LogIt().append('Uploaded event : ' + str(local_event.title))
       except (StandardError,gdata.service.Error,gdata.service.RequestError,socket.error) ,error:
         import traceback
         trace = str(traceback.print_exc())
@@ -215,7 +216,9 @@ class GSync:
 
   def sync_events_localy_updated(self,gcal):
     LogIt().append('Updating events to google')
+#    gcal.last_update = gcal.last_update.replace(tzinfo=dateutil.tz.tzutc())
     uuid_list = EventList().get_event_not_updated_since(gcal.last_update)
+#    LogIt().append('DEBUG:localy_updated:'+str(gcal.last_update))
     for local_event_uuid in uuid_list:
       local_event = Event(local_event_uuid)
       try:
@@ -238,7 +241,8 @@ class GSync:
           distant_event = self.cal_client.UpdateEvent(edit_link.href, distant_event)
         local_event.google_event_id = distant_event.id.text
         local_event.google_cal_id = urllib.unquote(local_event.google_event_id.split('/')[5])  
-        local_event.save_to_db() 
+        local_event.save_to_db()
+        LogIt().append('Downloaded event : ' + str(local_event.title))
       except (StandardError,gdata.service.Error,gdata.service.RequestError,socket.error) ,error:
         import traceback
         trace = str(traceback.print_exc())
@@ -257,7 +261,9 @@ class GSync:
     while(query_no_more_result == False):
       try:
         query = gdata.calendar.service.CalendarEventQuery(gcal.gcal_id, 'private', 'composite', None, {"ctz":"utc"})
-        query.updated_min = self.convert_local_datetime(gcal.last_update)
+        gcal.last_update = gcal.last_update.replace(tzinfo=dateutil.tz.tzlocal())
+        query.updated_min = self.convert_local_datetime(gcal.last_update.astimezone(dateutil.tz.tzutc()))
+#        LogIt().append('DEBUG:query.updated_min:'+str(query.updated_min))
 #        query.updated_min = self.convert_local_datetime(datetime.datetime(2008,10,10,0,0,0))
         query.max_results = 1
         query.start_index = str(query_index)
@@ -354,7 +360,7 @@ class GSync:
         LogIt().append('No calendar to sync')
 
     LogIt().append('Sync finished')
-    
+
 if __name__ == "__main__":
   import mcalendar_prefs
   LogIt().append('Launching autosync')
